==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebGridScrollEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridScrollEventArgsDetailDescriptionMetadata } from "./WebGridScrollEventArgsDetailDescriptionMetadata";
import { WebGridScrollEventArgsDescription } from "./WebGridScrollEventArgsDescription";
/**
 * @hidden
 */
export let WebGridScrollEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridScrollEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridScrollEventArgsDescriptionMetadata.a == null) {
                WebGridScrollEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridScrollEventArgsDescriptionMetadata.c(WebGridScrollEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebGridScrollEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebGridScrollEventArgsDescriptionMetadata.a);
            WebGridScrollEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridScrollEventArgs");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebGridScrollEventArgsDetail");
        }
        static d(a) {
            WebGridScrollEventArgsDescriptionMetadata.b(a);
            a.ad("WebGridScrollEventArgs", () => new WebGridScrollEventArgsDescription());
            a.ac("WebGridScrollEventArgs", WebGridScrollEventArgsDescriptionMetadata.a);
        }
    }
    WebGridScrollEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridScrollEventArgsDescriptionMetadata, 'WebGridScrollEventArgsDescriptionMetadata');
    WebGridScrollEventArgsDescriptionMetadata.a = null;
    return WebGridScrollEventArgsDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/WebGridScrollEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridScrollEventArgsDetailDescriptionMetadata } from "./WebGridScrollEventArgsDetailDescriptionMetadata";
import { WebGridScrollEventArgsDescription } from "./WebGridScrollEventArgsDescription";
/**
 * @hidden
 */
export let WebGridScrollEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridScrollEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridScrollEventArgsDescriptionMetadata.a == null) {
                WebGridScrollEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridScrollEventArgsDescriptionMetadata.c(WebGridScrollEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebGridScrollEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebGridScrollEventArgsDescriptionMetadata.a);
            WebGridScrollEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridScrollEventArgs");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebGridScrollEventArgsDetail");
        }
        static d(a) {
            WebGridScrollEventArgsDescriptionMetadata.b(a);
            a.ae("WebGridScrollEventArgs", () => new WebGridScrollEventArgsDescription());
            a.ad("WebGridScrollEventArgs", WebGridScrollEventArgsDescriptionMetadata.a);
        }
    }
    WebGridScrollEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridScrollEventArgsDescriptionMetadata, 'WebGridScrollEventArgsDescriptionMetadata');
    WebGridScrollEventArgsDescriptionMetadata.a = null;
    return WebGridScrollEventArgsDescriptionMetadata;
})();
